==> jc-1.4.0.tar.gz: gnu/xml/aelfred2/JAXPFactory.h <==
// public final class gnu.xml.aelfred2.JAXPFactory

// class file dependencies
// @dep_class 47d67ee83c3b4e01 gnu_xml_aelfred2_JAXPFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 86e754aa89cca8e1 javax_xml_parsers_SAXParserFactory

// header file dependencies
// @dep_header javax_xml_parsers_SAXParserFactory

#include "javax/xml/parsers/SAXParserFactory.h"

#ifndef _JC_gnu_xml_aelfred2_JAXPFactory_H_
#define _JC_gnu_xml_aelfred2_JAXPFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_xml_parsers_SAXParser$object;

// Typedefs
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_refs	_jc_gnu_xml_aelfred2_JAXPFactory$sub_refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$refs	_jc_gnu_xml_aelfred2_JAXPFactory$refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory$nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$object	_jc_gnu_xml_aelfred2_JAXPFactory$object;

typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory$vmethods	_jc_gnu_xml_aelfred2_JAXPFactory$vmethods;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory$vtable	_jc_gnu_xml_aelfred2_JAXPFactory$vtable;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory$vtype	_jc_gnu_xml_aelfred2_JAXPFactory$vtype;

// Constructors
extern void _jc_gnu_xml_aelfred2_JAXPFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *);

// Virtual methods
extern jboolean _jc_gnu_xml_aelfred2_JAXPFactory$method$getFeature$1f81e149fe4bca3b(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_xml_parsers_SAXParser$object *_jc_gnu_xml_aelfred2_JAXPFactory$method$newSAXParser$f0f8ffdd5540228d(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *);
extern void _jc_gnu_xml_aelfred2_JAXPFactory$method$setFeature$907897e626165cee(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_gnu_xml_aelfred2_JAXPFactory$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$getFeature$1f81e149fe4bca3b;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$newSAXParser$f0f8ffdd5540228d;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$setFeature$907897e626165cee;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_aelfred2_JAXPFactory$vmethods {
	jboolean	(*getFeature$1f81e149fe4bca3b)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *);
	struct _jc_javax_xml_parsers_SAXParser$object	*(*newSAXParser$f0f8ffdd5540228d)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *);
	void	(*setFeature$907897e626165cee)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *, jboolean);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *);
};

// Vtable
struct _jc_gnu_xml_aelfred2_JAXPFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParserFactory$vmethods	javax_xml_parsers_SAXParserFactory;
	_jc_gnu_xml_aelfred2_JAXPFactory$vmethods	gnu_xml_aelfred2_JAXPFactory;
};

// Vtype
struct _jc_gnu_xml_aelfred2_JAXPFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_aelfred2_JAXPFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_refs {
	struct _jc_java_util_Hashtable$object	*flags;
};

// Reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory$refs {
    _jc_gnu_xml_aelfred2_JAXPFactory$sub_refs	gnu_xml_aelfred2_JAXPFactory;
    _jc_javax_xml_parsers_SAXParserFactory$sub_refs	javax_xml_parsers_SAXParserFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParserFactory$sub_nonrefs	javax_xml_parsers_SAXParserFactory;
    _jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs	gnu_xml_aelfred2_JAXPFactory;
};

// Object instance structure
struct _jc_gnu_xml_aelfred2_JAXPFactory$object {
	_jc_gnu_xml_aelfred2_JAXPFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_aelfred2_JAXPFactory$vtype	*vtype;
	_jc_gnu_xml_aelfred2_JAXPFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_aelfred2_JAXPFactory$vtype _jc_gnu_xml_aelfred2_JAXPFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_aelfred2_JAXPFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_aelfred2_JAXPFactory$class_object;

#endif	/* _JC_gnu_xml_aelfred2_JAXPFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/aelfred2/JAXPFactory.h <==
// public final class gnu.xml.aelfred2.JAXPFactory

// class file dependencies
// @dep_class c20dbeac651a5e85 gnu_xml_aelfred2_JAXPFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 86e754aa89cca8e1 javax_xml_parsers_SAXParserFactory

// header file dependencies
// @dep_header javax_xml_parsers_SAXParserFactory

#include "javax/xml/parsers/SAXParserFactory.h"

#ifndef _JC_gnu_xml_aelfred2_JAXPFactory_H_
#define _JC_gnu_xml_aelfred2_JAXPFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_xml_parsers_SAXParser$object;

// Typedefs
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_refs	_jc_gnu_xml_aelfred2_JAXPFactory$sub_refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$refs	_jc_gnu_xml_aelfred2_JAXPFactory$refs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$nonrefs	_jc_gnu_xml_aelfred2_JAXPFactory$nonrefs;
typedef struct _jc_gnu_xml_aelfred2_JAXPFactory$object	_jc_gnu_xml_aelfred2_JAXPFactory$object;

typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory$vmethods	_jc_gnu_xml_aelfred2_JAXPFactory$vmethods;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory$vtable	_jc_gnu_xml_aelfred2_JAXPFactory$vtable;
typedef const struct _jc_gnu_xml_aelfred2_JAXPFactory$vtype	_jc_gnu_xml_aelfred2_JAXPFactory$vtype;

// Constructors
extern void _jc_gnu_xml_aelfred2_JAXPFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_aelfred2_JAXPFactory$method$getFeature$1f81e149fe4bca3b(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_parsers_SAXParser$object *_jc_gnu_xml_aelfred2_JAXPFactory$method$newSAXParser$f0f8ffdd5540228d(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_aelfred2_JAXPFactory$method$setFeature$907897e626165cee(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_aelfred2_JAXPFactory$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$getFeature$1f81e149fe4bca3b;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$newSAXParser$f0f8ffdd5540228d;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$setFeature$907897e626165cee;
extern _jc_method _jc_gnu_xml_aelfred2_JAXPFactory$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_xml_aelfred2_JAXPFactory$vmethods {
	jboolean	(*getFeature$1f81e149fe4bca3b)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_parsers_SAXParser$object	*(*newSAXParser$f0f8ffdd5540228d)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *) _JC_JCNI_ATTR;
	void	(*setFeature$907897e626165cee)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_xml_aelfred2_JAXPFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_aelfred2_JAXPFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_SAXParserFactory$vmethods	javax_xml_parsers_SAXParserFactory;
	_jc_gnu_xml_aelfred2_JAXPFactory$vmethods	gnu_xml_aelfred2_JAXPFactory;
};

// Vtype
struct _jc_gnu_xml_aelfred2_JAXPFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_aelfred2_JAXPFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_refs {
	struct _jc_java_util_Hashtable$object	*flags;
};

// Reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory$refs {
    _jc_gnu_xml_aelfred2_JAXPFactory$sub_refs	gnu_xml_aelfred2_JAXPFactory;
    _jc_javax_xml_parsers_SAXParserFactory$sub_refs	javax_xml_parsers_SAXParserFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_aelfred2_JAXPFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_SAXParserFactory$sub_nonrefs	javax_xml_parsers_SAXParserFactory;
    _jc_gnu_xml_aelfred2_JAXPFactory$sub_nonrefs	gnu_xml_aelfred2_JAXPFactory;
};

// Object instance structure
struct _jc_gnu_xml_aelfred2_JAXPFactory$object {
	_jc_gnu_xml_aelfred2_JAXPFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_aelfred2_JAXPFactory$vtype	*vtype;
	_jc_gnu_xml_aelfred2_JAXPFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_aelfred2_JAXPFactory$vtype _jc_gnu_xml_aelfred2_JAXPFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_aelfred2_JAXPFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_aelfred2_JAXPFactory$class_object;

#endif	/* _JC_gnu_xml_aelfred2_JAXPFactory_H_ */
